@@ -10,21 +10,25 @@ import (
 	"github.com/aws/aws-sdk-go/service/cloudwatch"
 	"github.com/aws/aws-sdk-go/service/cloudwatch/cloudwatchiface"
 
-	"github.com/go-kit/kit/log"
 	"github.com/go-kit/kit/metrics"
 	"github.com/go-kit/kit/metrics/teststat"
+	"github.com/go-kit/log"
 )
 
+const metricNameToGenerateError = "metric_name_used_to_throw_an_error"
+
+var errTest = errors.New("test error")
+
 type mockCloudWatch struct {
 	cloudwatchiface.CloudWatchAPI
 	mtx                sync.RWMutex
-	valuesReceived     map[string]float64
+	valuesReceived     map[string][]float64
 	dimensionsReceived map[string][]*cloudwatch.Dimension
 }
 
 func newMockCloudWatch() *mockCloudWatch {
 	return &mockCloudWatch{
-		valuesReceived:     map[string]float64{},
+		valuesReceived:     map[string][]float64{},
 		dimensionsReceived: map[string][]*cloudwatch.Dimension{},
 	}
 }
@@ -33,7 +37,17 @@ func (mcw *mockCloudWatch) PutMetricData(input *cloudwatch.PutMetricDataInput) (
 	mcw.mtx.Lock()
 	defer mcw.mtx.Unlock()
 	for _, datum := range input.MetricData {
-		mcw.valuesReceived[*datum.MetricName] = *datum.Value
+		if *datum.MetricName == metricNameToGenerateError {
+			return nil, errTest
+		}
+
+		if len(datum.Values) > 0 {
+			for _, v := range datum.Values {
+				mcw.valuesReceived[*datum.MetricName] = append(mcw.valuesReceived[*datum.MetricName], *v)
+			}
+		} else {
+			mcw.valuesReceived[*datum.MetricName] = append(mcw.valuesReceived[*datum.MetricName], *datum.Value)
+		}
 		mcw.dimensionsReceived[*datum.MetricName] = datum.Dimensions
 	}
 	return nil, nil
@@ -76,13 +90,15 @@ func TestCounter(t *testing.T) {
 	cw := New(namespace, svc, WithLogger(log.NewNopLogger()))
 	counter := cw.NewCounter(name).With(label, value)
 	valuef := func() float64 {
-		err := cw.Send()
-		if err != nil {
+		if err := cw.Send(); err != nil {
 			t.Fatal(err)
 		}
 		svc.mtx.RLock()
 		defer svc.mtx.RUnlock()
-		return svc.valuesReceived[name]
+		value := svc.valuesReceived[name][len(svc.valuesReceived[name])-1]
+		delete(svc.valuesReceived, name)
+
+		return value
 	}
 	if err := teststat.TestCounter(counter, valuef); err != nil {
 		t.Fatal(err)
@@ -117,13 +133,18 @@ func TestCounterLowSendConcurrency(t *testing.T) {
 		wants = append(wants, teststat.FillCounter(counters[name]))
 	}
 
-	err := cw.Send()
-	if err != nil {
+	if err := cw.Send(); err != nil {
 		t.Fatal(err)
 	}
 
 	for i, name := range names {
-		if svc.valuesReceived[name] != wants[i] {
+		if l := len(svc.valuesReceived[name]); l == 0 && wants[i] == 0 {
+			continue
+		} else if l != 1 {
+			t.Fatalf("one value expected, got %d", l)
+		}
+
+		if svc.valuesReceived[name][0] != wants[i] {
 			t.Fatalf("want %f, have %f", wants[i], svc.valuesReceived[name])
 		}
 		if err := svc.testDimensions(name, labels[i], values[i]); err != nil {
@@ -138,15 +159,17 @@ func TestGauge(t *testing.T) {
 	svc := newMockCloudWatch()
 	cw := New(namespace, svc, WithLogger(log.NewNopLogger()))
 	gauge := cw.NewGauge(name).With(label, value)
-	valuef := func() float64 {
-		err := cw.Send()
-		if err != nil {
+	valuef := func() []float64 {
+		if err := cw.Send(); err != nil {
 			t.Fatal(err)
 		}
 		svc.mtx.RLock()
 		defer svc.mtx.RUnlock()
-		return svc.valuesReceived[name]
+		res := svc.valuesReceived[name]
+		delete(svc.valuesReceived, name)
+		return res
 	}
+
 	if err := teststat.TestGauge(gauge, valuef); err != nil {
 		t.Fatal(err)
 	}
@@ -170,12 +193,28 @@ func TestHistogram(t *testing.T) {
 		if err != nil {
 			t.Fatal(err)
 		}
+
 		svc.mtx.RLock()
 		defer svc.mtx.RUnlock()
-		p50 = svc.valuesReceived[n50]
-		p90 = svc.valuesReceived[n90]
-		p95 = svc.valuesReceived[n95]
-		p99 = svc.valuesReceived[n99]
+		if len(svc.valuesReceived[n50]) > 0 {
+			p50 = svc.valuesReceived[n50][0]
+			delete(svc.valuesReceived, n50)
+		}
+
+		if len(svc.valuesReceived[n90]) > 0 {
+			p90 = svc.valuesReceived[n90][0]
+			delete(svc.valuesReceived, n90)
+		}
+
+		if len(svc.valuesReceived[n95]) > 0 {
+			p95 = svc.valuesReceived[n95][0]
+			delete(svc.valuesReceived, n95)
+		}
+
+		if len(svc.valuesReceived[n99]) > 0 {
+			p99 = svc.valuesReceived[n99][0]
+			delete(svc.valuesReceived, n99)
+		}
 		return
 	}
 	if err := teststat.TestHistogram(histogram, quantiles, 0.01); err != nil {
@@ -207,8 +246,14 @@ func TestHistogram(t *testing.T) {
 		}
 		svc.mtx.RLock()
 		defer svc.mtx.RUnlock()
-		p50 = svc.valuesReceived[n50]
-		p90 = svc.valuesReceived[n90]
+		if len(svc.valuesReceived[n50]) > 0 {
+			p50 = svc.valuesReceived[n50][0]
+			delete(svc.valuesReceived, n50)
+		}
+		if len(svc.valuesReceived[n90]) > 0 {
+			p90 = svc.valuesReceived[n90][0]
+			delete(svc.valuesReceived, n90)
+		}
 
 		// our teststat.TestHistogram wants us to give p95 and p99,
 		// but with custom percentiles we don't have those.
@@ -242,3 +287,13 @@ func TestHistogram(t *testing.T) {
 		t.Fatal(err)
 	}
 }
+
+func TestErrorLog(t *testing.T) {
+	namespace := "abc"
+	svc := newMockCloudWatch()
+	cw := New(namespace, svc, WithLogger(log.NewNopLogger()))
+	cw.NewGauge(metricNameToGenerateError).Set(123)
+	if err := cw.Send(); err != errTest {
+		t.Fatal("Expected error, but didn't get one")
+	}
+}
