@@ -7,8 +7,8 @@ import (
 	"google.golang.org/grpc/metadata"
 
 	"github.com/go-kit/kit/endpoint"
-	"github.com/go-kit/kit/log"
 	"github.com/go-kit/kit/transport"
+	"github.com/go-kit/log"
 )
 
 // Handler which should be called from the gRPC binding of the service
